### R code from vignette source 'TBSSurvival.Rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: TBSSurvival.Rnw:108-110
###################################################
options(width=60)
set.seed(1234)


###################################################
### code chunk number 2: example1
###################################################
time <- pmin(rgamma(30,10,2),rep(6,30))
delta <- rep(1,30)
for (i in 1:30) {
  if (time[i] == 6) delta[i] <- 0
}
data <- cbind(time,delta)
data


###################################################
### code chunk number 3: tbsinst (eval = FALSE)
###################################################
## install.packages("TBSSurvival_VERSION.tar.gz",repos=NULL,type="source")


###################################################
### code chunk number 4: <tbs
###################################################
library("TBSSurvival")


###################################################
### code chunk number 5: fig1a
###################################################
x <- seq(0.1,10,0.1)
plot(x, (1-ptbs(x,lambda=1,xi=sqrt(2),beta=1,
                dist="norm")),
     type="l",lwd=2,lty=1,col=2,ylim=c(0,1),xlab="t",
     ylab="R(t)",main="Reliability",cex.lab=1.2)


###################################################
### code chunk number 6: fig1b
###################################################
plot(x, (dtbs(x,lambda=1,xi=sqrt(2),beta=1,
              dist="norm")),
     type="l",lwd=2,lty=1,col=2,xlab="t",
     ylab="f(t)",main="Density",cex.lab=1.2)


###################################################
### code chunk number 7: fig1c
###################################################
plot(x, (htbs(x,lambda=1,xi=sqrt(2),beta=1,
              dist="norm")),
     type="l",lwd=2,lty=1,col=2,xlab="t",
     ylab="h(t)",main="Hazard",cex.lab=1.2)


###################################################
### code chunk number 8: fig2a
###################################################
x <- seq(0.1,10,0.1)
plot(x, (1-ptbs(x, lambda=1, xi=1, beta=1, dist="doubexp")),
     type="l", lwd=2, lty=1, col=2, ylim=c(0,1), xlab="t", 
     ylab="R(t)", main="Reliability", cex.lab=1.2)


###################################################
### code chunk number 9: fig2b
###################################################
plot(x, (dtbs(x, lambda=1, xi=1, beta=1, dist="doubexp")),
     type="l", lwd=2, lty=1, col=2, xlab="t", ylab="f(t)",
     main="Density", cex.lab=1.2)


###################################################
### code chunk number 10: fig2c
###################################################
plot(x, (htbs(x, lambda=1, xi=1, beta=1, 
                    dist="doubexp")), type="l", lwd=2, 
     lty=1, col=2, xlab="t", ylab="h(t)",
     main="Hazard", cex.lab=1.2)


###################################################
### code chunk number 11: mle
###################################################
formula <- Surv(data[,1],data[,2]) ~ 1
tbs.mle <- tbs.survreg.mle(formula,dist="norm", nstart=3,
                           method="Nelder-Mead")
tbs.mle


###################################################
### code chunk number 12: mlekm
###################################################
# Kaplan-Meier estimation
km <- survfit(formula)


###################################################
### code chunk number 13: mlekm
###################################################
plot(km,ylab="R(t)", xlab="t: number of cycles (in thousands)",
     main="Reliability function (MLE)", conf.int=FALSE, lty=1, 
     lwd=1, xlim=c(min(data[,1]),max(data[,1])))
t <- seq(min(data[,1]),max(data[,1]),
         (max(data[,1])-min(data[,1])-0.01)/1000)
legend(2.6,0.2,
   c("Kaplan-Meier",
     expression(textstyle(paste("TBS / ",sep="")) ~ epsilon
         ~ textstyle(paste("~",sep="")) ~ Norm)),
   col=c(1,2),lty=c(1,1),cex=1.1,lwd=c(1,2),bg="white")
lines(t,1-ptbs(t, lambda=tbs.mle$par[1], xi=tbs.mle$par[2],
               beta=tbs.mle$par[3], 
               dist=tbs.mle$error.dist), type="l",
      lwd=2, col=2, lty=1)


###################################################
### code chunk number 14: covars (eval = FALSE)
###################################################
## library(survival)
## data(colon)
## ## Running MLE on colon (from survival package) with a covariate
## colon$age60=as.numeric(colon$age>60) #threshold defined from medical papers
## s=tbs.survreg.mle(Surv(colon$time,colon$status==1) ~ colon$age60,
##       dist="norm",method=c("Nelder-Mead"),nstart=3,verbose=FALSE)


###################################################
### code chunk number 15: be
###################################################
tbs.be <- tbs.survreg.be(formula,dist="norm",
                         guess.lambda=2,guess.xi=4,
                         guess.beta=1.5,burn=1000,
                         jump=10,size=1000,scale=0.06)


###################################################
### code chunk number 16: bekm
###################################################
aux.survival <- matrix(0,length(tbs.be$time),1000)
for (j in 1:1000) {
  aux.survival[,j] <- 
    c(1-ptbs(tbs.be$time,
             lambda=tbs.be$post[j,1],
             xi=tbs.be$post[j,2],
             beta=tbs.be$post[j,3:length(tbs.be$post[1,])],
             x=tbs.be$x,dist="norm"))
}
survival <- matrix(0,length(tbs.be$time),8)
for (i in 1:length(tbs.be$time)) {
  survival[i,] <- 
    c(summary(aux.survival[i,]),
      HPDinterval(as.mcmc(aux.survival[i,]),0.95))
}
tbs.be$survival <- survival

plot(km,ylab="R(t)", 
     xlab="t: number of cycles (in thousands)",
     main="Reliability function (BE)", conf.int=FALSE, 
     lty=1, lwd=1, xlim=c(min(data[,1]),max(data[,1])))
legend(2.6,0.3,
  c("Kaplan-Meier",
    expression(textstyle(paste("TBS / ",sep="")) ~ epsilon
        ~ textstyle(paste("~",sep="")) ~ Logistic),
    "95% HPD Interval"),
  col=c(1,2,2),lty=c(1,1,2),cex=1.1,lwd=c(1,2,2),
  bg="white")
lines(tbs.be$time,tbs.be$survival[,3],type="l",lwd=2,col=2,
      lty=1)
lines(tbs.be$time,tbs.be$survival[,7],type="l",lwd=2,col=2,
      lty=2)
lines(tbs.be$time,tbs.be$survival[,8],type="l",lwd=2,col=2,
      lty=2)


